aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorjmarshallnz <jcmarsha@gmail.com>2014-02-28 08:50:10 +1300
committerjmarshallnz <jcmarsha@gmail.com>2014-02-28 08:50:10 +1300
commit0041648f7771789db94cee55d9468e44d0d327f3 (patch)
treee574bd8b95d7a611fda7a5bc194fe425d374369c
parentc73e80346278a71d656295a261ceb83b739ae99d (diff)
parent753cdc977d40d3119d59042ba22a752bac6e44a0 (diff)
Merge pull request #4286 from arnova/stack_streamdetails_fix
fixed: Auto extracted stream details were never stored the stacks
-rw-r--r--xbmc/video/VideoThumbLoader.cpp8
1 files changed, 7 insertions, 1 deletions
diff --git a/xbmc/video/VideoThumbLoader.cpp b/xbmc/video/VideoThumbLoader.cpp
index 418400f7b0..04da6f0476 100644
--- a/xbmc/video/VideoThumbLoader.cpp
+++ b/xbmc/video/VideoThumbLoader.cpp
@@ -135,7 +135,13 @@ bool CThumbExtractor::DoWork()
if (db.Open())
{
if (URIUtils::IsStack(m_listpath))
- m_item.GetVideoInfoTag()->m_streamDetails.SetVideoDuration(0, 0); // Don't know the total time of the stack, so set duration to zero to avoid confusion
+ {
+ // Don't know the total time of the stack, so set duration to zero to avoid confusion
+ m_item.GetVideoInfoTag()->m_streamDetails.SetVideoDuration(0, 0);
+
+ // Restore original stack path
+ m_item.SetPath(m_listpath);
+ }
if (info->m_iFileId < 0)
db.SetStreamDetailsForFile(info->m_streamDetails, !info->m_strFileNameAndPath.empty() ? info->m_strFileNameAndPath : m_item.GetPath());